@@ -397,17 +397,6 @@ void get_automatic_bbox (void)
 
   first_values_set = 0;
 
-#ifndef GL
-  if (atom_flag == 1)
-    {
-      atom_size = atoms[i].cov_rad * get_atom_scale ();
-    }
-  else
-    {
-      atom_size = 0;
-    }
-#endif  /* GL */
-
   for (i = 0; i < no_atoms; i++)
     {
       double atom_size = 0;
@@ -431,6 +420,15 @@ void get_automatic_bbox (void)
                   atom_size = 0;
                 }
             }
+#else
+  	  if (atom_flag == 1)
+    	    {
+      	      atom_size = atoms[i].cov_rad * get_atom_scale ();
+            }
+          else
+            {
+              atom_size = 0;
+            }
 #endif  /* GL */
 
           if (first_values_set == 0)
@@ -459,7 +457,7 @@ void get_automatic_bbox (void)
             {
               bbox.y_min = (atoms[i].g[1] - atom_size);
             }
-          else if ((atoms[i].g[1] + atom_size) >bbox.y_max)
+          else if ((atoms[i].g[1] + atom_size) > bbox.y_max)
             {
               bbox.y_max = (atoms[i].g[1] + atom_size);
             }
