@@ -22,21 +22,22 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #ifndef __BBOX_H__
 #define __BBOX_H__
 
-struct bounding_box {
-  double x_max,x_min;
-  double y_max,y_min;
-  double z_max,z_min;
-  double v[8][3];
-};
-
+enum bbox_type {AUTOMATIC, FROM_FILE};
 
 #ifdef __BBOX_C__
 
-struct bounding_box bbox;
+bounding_box bbox;
+enum bbox_type bbox_type = AUTOMATIC;
+Widget bbox_dialog = NULL;  /* wjq */
+Widget bbMin[4], bbMax[4];  /* 0:     The whole entry line for Min, Max values,
+                               1,2,3: Entry fields for x,y,z respectively       */
 
 #else  /* __BBOX_C__ */
 
-extern struct bounding_box bbox;
+extern bounding_box bbox;
+extern enum bbox_type bbox_type;
+extern Widget bbox_dialog;
+extern Widget bbMin[4], bbMax[4];
 
 #endif /* __BBOX_C__ */
 
