@@ -260,7 +260,7 @@ measure(Widget parent)
     select_atom_w=XtVaCreateManagedWidget
       ("select",xmTextFieldWidgetClass,meas_rc[0], NULL);
 
-    XtAddCallback(select_atom_w,XmNlosingFocusCallback,select_atom_cb,NULL);
+    XtAddCallback(select_atom_w,XmNactivateCallback,select_atom_cb,NULL);
 
     sep=XmCreateSeparator(meas_rc[0],"sep",NULL,0);
     XtManageChild(sep);
@@ -748,7 +748,12 @@ select_atom_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 
   XtVaGetValues(widget,XmNvalue,&selected_atom_str,NULL);
 
-  sscanf(selected_atom_str,"%d",&selected_atom);
+  if ((strlen (selected_atom_str) == 0) ||
+      (sscanf (selected_atom_str, "%d", &selected_atom) <= 0))
+    {
+      echo_to_message_area("Cannot parse string!");
+      return;
+    }
 
   selected_atom--;  /* 0..no_atoms-1 */
 
