@@ -25,8 +25,8 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <Xm/Xm.h>
 
-#include "bbox.h"
 #include "globals.h"
+#include "bbox.h"
 
 static int crystal_origin_set = 0;
 static int crystal_vector_set[3] = {0, 0, 0};
@@ -107,7 +107,7 @@ void reset_crystal_status (void)
   crystal_vector_set[2] = 0;
 }
 
-void update_crystal_bbox (struct bounding_box *bbox)
+void update_crystal_bbox (bounding_box *bbox)
 {
   double get_angle_axis (double *);
   void rotate (double *);
