@@ -576,6 +576,7 @@ void
 save_anim_cb(Widget widget, XtPointer client_data, XtPointer call_data)
 {
   void change_frame(int, Boolean, Boolean);
+  void set_current_directory (XmString dir);
 #ifdef GL
   void set_gl_copy_canvas (int);
 #endif
@@ -708,6 +709,8 @@ change_frame(int frame_no, Boolean update_label, Boolean centre_this_frame)
 
   if(no_frames == 0) return;
 
+  changing_frame = True;
+
   frame_content_to_atoms (frame_no);
 
   /* Centre frame if required, by modifying global_vector[] */
@@ -736,7 +739,8 @@ change_frame(int frame_no, Boolean update_label, Boolean centre_this_frame)
   canvas_cb(canvas,NULL,NULL);
 
   update_frame_label();
-  
+
+  changing_frame = False;
 }
 
 
