@@ -97,7 +97,8 @@ void gl_render (void)
   void set_gl_render_stereo(enum render_stereo_types);
   void StereoProjection(float left, float right, float bottom,
                         float top, float near, float far,
-                        float zero_plane, float dist, float eye);
+                        float zero_plane, float dist, float eye,
+                        int side_by_side);
   double get_canvas_scale(void);
   double get_z_depth(void);
   
@@ -106,6 +107,8 @@ void gl_render (void)
   
   double scale, depth, width_scale, height_scale;
 
+  int side_by_side;
+
   if (gl_initialized == 0)
     {
       gl_init ();
@@ -135,6 +138,10 @@ void gl_render (void)
 
   gluLookAt (0.0, 0.0, gl_eye, 0.0, 0.0, 0.0, 0.0, 1.0, 0.0);
 
+  /* This may get changed in StereoProjection, but isn't reset when we
+     change back to a single image */
+  glViewport (0, 0, canvas_width, canvas_height);
+
   /* aro--> */
   if(get_gl_render_stereo() && depth_is_on)
     {
@@ -156,14 +163,29 @@ void gl_render (void)
       /* Create nonsymetric viewing frustum */
       glMatrixMode(GL_PROJECTION);
       glLoadIdentity();
+
+      if (get_gl_render_stereo() == SIDE_BY_SIDE)
+        {
+          side_by_side = 1;
+        }
+      else
+        {
+          side_by_side = 0;
+        }
+
       StereoProjection(-zp_width, zp_width, -zp_width, zp_width, 
                        gl_perspective_near, gl_perspective_far, 
-                       0.0, gl_eye, -eye_offset);
+                       0.0, gl_eye, -eye_offset, side_by_side);
 
-      if(get_gl_render_stereo() == RED_BLUE) {
+      if(get_gl_render_stereo() == SIDE_BY_SIDE) { 
         glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
-        glColorMask(GL_TRUE, GL_FALSE, GL_FALSE, GL_TRUE);/* Red mask */
+/*         glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE); */
       }
+      else if (get_gl_render_stereo() == RED_BLUE)
+        {
+          glClear (GL_COLOR_BUFFER_BIT | GL_DEPTH_BUFFER_BIT);
+          glColorMask(GL_TRUE, GL_FALSE, GL_FALSE, GL_TRUE);/* Red mask */
+        }
 #ifdef SGI_STEREO
       else if(get_gl_render_stereo() == SGI_HARDWARE) {
         glXWaitGL();
@@ -223,14 +245,20 @@ void gl_render (void)
       /* Create nonsymetric viewing frustum */
       glMatrixMode(GL_PROJECTION);
       glLoadIdentity();
+
       StereoProjection(-zp_width, zp_width, -zp_width, zp_width, 
                        gl_perspective_near, gl_perspective_far, 
-                       0.0, gl_eye, eye_offset);
-      
-      if(get_gl_render_stereo() == RED_BLUE) {
-        glColorMask(GL_FALSE, GL_FALSE, GL_TRUE, GL_TRUE);/* Blue mask */
-        glClear(GL_DEPTH_BUFFER_BIT);
+                       0.0, gl_eye, eye_offset, -side_by_side);
+
+      if(get_gl_render_stereo() == SIDE_BY_SIDE) {
+/*         glColorMask(GL_TRUE, GL_TRUE, GL_TRUE, GL_TRUE); */
+/*         glClear(GL_DEPTH_BUFFER_BIT); */
       }
+      else if (get_gl_render_stereo() == RED_BLUE)
+        {
+          glColorMask(GL_FALSE, GL_FALSE, GL_TRUE, GL_TRUE);/* Blue mask */
+          glClear(GL_DEPTH_BUFFER_BIT);
+        }
 #ifdef SGI_STEREO
       else if(get_gl_render_stereo() == SGI_HARDWARE) {
         glXWaitGL();
@@ -289,7 +317,7 @@ void gl_render (void)
     }
 
   /* aro - change color mask so all of RGB color fields are cleared */
-  if((get_gl_render_stereo() == RED_BLUE) && depth_is_on)
+  if ((get_gl_render_stereo() == RED_BLUE) && depth_is_on)
     glColorMask(GL_TRUE,GL_TRUE,GL_TRUE,GL_TRUE);
   
   /* Note that we are drawing onto the canvas directly, since I
@@ -310,7 +338,7 @@ void gl_render (void)
 
 void StereoProjection(float left, float right, float bottom, float top,
                       float near, float far, float zero_plane, float dist,
-                      float eye)
+                      float eye, int side_by_side)
 {
   enum render_stereo_types get_gl_render_stereo();
   
@@ -328,7 +356,36 @@ void StereoProjection(float left, float right, float bottom, float top,
   
   static double last_near;
   static double last_far;
-  
+
+  /* Viewports for side by side mode */
+
+  if (side_by_side == 1)
+    {
+      glViewport (canvas_width / 2, 0, canvas_width / 2, canvas_height);
+      left *= 0.5;
+      right *= 0.5;
+    }
+  else if (side_by_side == -1)
+    {
+      glViewport (0, 0, canvas_width, canvas_height);
+      glColor3f (0.0, 0.0, 0.0);
+      glLineWidth (2.0);
+
+      glBegin (GL_LINES);
+      /* FIXME: do this properly */
+      glVertex3f (0.0, -1000, 0.0);
+      glVertex3f (0.0, 1000, 0.0);
+      glEnd ();
+
+      glViewport (0, 0, canvas_width / 2, canvas_height);
+      left *= 0.5;
+      right *= 0.5;
+    }
+  else
+    {
+      glViewport (0, 0, canvas_width, canvas_height);
+    }
+
   dx = right - left;
   dy = top - bottom;
   
@@ -355,11 +412,10 @@ void StereoProjection(float left, float right, float bottom, float top,
   bottomw = -topw;
   rightw = n_over_d * (dx / 2.0 - eye);
   leftw  = n_over_d *(-dx / 2.0 - eye);
-  
+
   /* Need to be in projection mode for this. */
   glLoadIdentity();
   glFrustum(leftw, rightw, bottomw, topw, clip_near, clip_far);
-  
   glTranslatef(-xmid - eye,  -ymid,  -zero_plane - dist);
 }
 
@@ -417,7 +473,7 @@ void gl_render_atom (int i)
 
   /* aro - We need to convert the colors to grayscale in order for 
      red and blue color masks to work properly */
-  if((get_gl_render_stereo() == RED_BLUE) && depth_is_on)
+  if ((get_gl_render_stereo() == RED_BLUE) && depth_is_on)
     {
       red = (red + blue + green) / 3;
       blue = red;
@@ -720,7 +776,7 @@ void gl_render_bond (int i,
 
   /* aro - We need to convert the colors to grayscale in order for 
      red and blue color masks to work properly */
-  if((get_gl_render_stereo() == RED_BLUE) && depth_is_on)
+  if ((get_gl_render_stereo() == RED_BLUE) && depth_is_on)
     {
       red = (red + blue + green) / 3;
       blue = red;
