@@ -29,8 +29,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 #include <Xm/Xm.h>
 
-#include "draw.h"
 #include "globals.h"
+#include "bbox.h"
+#include "draw.h"
 
 /* Code to actually alter the atomic x,y,z values. This routine accepts
    first the axis to rotate about, second the angle, third a logical
@@ -41,9 +42,9 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 void
 rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
 {
-
   void adjust_current_frame(void);
   void canvas_cb(Widget, XtPointer, XtPointer);
+  void clear_message_area (void);
   void deactivate_region(void);
   void normalize_vec(double *);
   void rotate(double *);
@@ -66,8 +67,9 @@ rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
   
   local_com[0] = local_com[1] = local_com[2] = 0;
   local_mass = 0;
-  
-  if(rotate_about == ROTATE_ABOUT_ORIGIN)
+
+  changing_frame = False;
+  if((rotate_about == ROTATE_ABOUT_ORIGIN) || changing_frame)
     {
       set_rotate_origin(NULL);
       for(i = 0; i < no_atoms; i++)
@@ -110,7 +112,6 @@ rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
               local_com[i] /= local_mass;
             }
         }
-      
       set_rotate_origin(local_com);
     }
   
@@ -121,7 +122,6 @@ rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
     {
       if((atoms[i].edit == 1) || (rot_subset == 0))
         {
-
           atom_coords[0] = atoms[i].x;
           atom_coords[1] = atoms[i].y;
           atom_coords[2] = atoms[i].z;
@@ -131,7 +131,14 @@ rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
           atoms[i].x = atom_coords[0];
           atoms[i].y = atom_coords[1];
           atoms[i].z = atom_coords[2];
+        }
+    }
 
+  if (bbox_available)
+    {
+      for (i = 0; i < 8; i++)
+        {
+          rotate (file_bbox.v[i]);
         }
     }
 
@@ -144,8 +151,6 @@ rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
     for(i=0;i<3;i++){
       rotate(global_matrix[i]);
     }
-    
-/*      store_coords(); */
   }
 
   if(!all_rotated){
@@ -153,8 +158,8 @@ rotate_atoms(double *axis, double phi, Boolean store_g, Boolean rot_subset)
   }
 
   rotate_vectors(axis, phi);
-  
-  update_bbox();
+
+  update_bbox ();
 
   deactivate_region();
 
