@@ -368,6 +368,7 @@ void
 select_atom_for_measure (void)
 {
   void update_selected(int);
+  void clear_message_area (void);
 
   char message[64];
   int closest;
@@ -862,9 +863,15 @@ reflect_x (void)
         {
           this_frame->atom[i].x *= -1.0;
         }
+
+      if (this_frame->bbox_available)
+        {
+          this_frame->bbox[0][0] *= -1.0;
+          this_frame->bbox[0][1] *= -1.0;
+        }
+
       this_frame = this_frame->next;
     }
-
 }
 
 
@@ -886,6 +893,13 @@ reflect_y (void)
         {
           this_frame->atom[i].y *= -1.0;
         }
+
+      if (this_frame->bbox_available)
+        {
+          this_frame->bbox[1][0] *= -1.0;
+          this_frame->bbox[1][1] *= -1.0;
+        }
+
       this_frame = this_frame->next;
     }
 
@@ -910,6 +924,13 @@ reflect_z (void)
         {
           this_frame->atom[i].z *= -1.0;
         }
+
+      if (this_frame->bbox_available)
+        {
+          this_frame->bbox[2][0] *= -1.0;
+          this_frame->bbox[2][1] *= -1.0;
+        }
+
       this_frame = this_frame->next;
     }
 
@@ -936,6 +957,17 @@ invert_coords (void)
           this_frame->atom[i].y *= -1.0;
           this_frame->atom[i].z *= -1.0;
         }
+
+      if (this_frame->bbox_available)
+        {
+          this_frame->bbox[0][0] *= -1.0;
+          this_frame->bbox[0][1] *= -1.0;
+          this_frame->bbox[1][0] *= -1.0;
+          this_frame->bbox[1][1] *= -1.0;
+          this_frame->bbox[2][0] *= -1.0;
+          this_frame->bbox[2][1] *= -1.0;
+        }
+
       this_frame = this_frame->next;
     }
 
