@@ -38,6 +38,7 @@ translate_atoms(double *vec)
   
   void adjust_current_frame(void);
   void canvas_cb(Widget, XtPointer, XtPointer);
+  void clear_message_area (void);
   void deactivate_region(void);
   void update_bbox(void);
   void update_bond_matrix(Boolean);
@@ -62,13 +63,23 @@ translate_atoms(double *vec)
         }
     }
 
+  if (bbox_available)
+    {
+      for (i = 0; i < 8; i++)
+        {
+          file_bbox.v[i][0] += vec[0];
+          file_bbox.v[i][1] += vec[1];
+          file_bbox.v[i][2] += vec[2];
+        }
+    }
+
   if(all_moved){
     for(i=0;i<3;i++){
       global_vector[i]+=vec[i];
     }
   }
 
-  update_bbox();
+  update_bbox ();
 
   redraw=1;
 
